from setuptools import setup, find_packages
import os

VERSION = '0.0.1'
DESCRIPTION = 'Trainable, efficient, autonomous routing.'
LONG_DESCRIPTION = 'Trainable, efficient, autonomous routing for data flowing through LLMs'

setup(
    name="TeaRoute",
    version=VERSION,
    author="kesile",
    author_email="johncolekessler@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['openai', 'numpy'],
    keywords=['python', 'ai', 'openai', 'chatgpt', 'routing', 'route'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


from .main import Tear
from .router.inner import Router
from .router.methods import chat, cos, embed, route, training
from chat import chat
from cos import cos
from embed import embed
from route import route
from training import trainWithFile
